@@ -1198,6 +1198,26 @@ hatTrace <- function(x)
     .Call(mer_hat_trace2, x)
 }
 
+## Check that the 'start' argument matches the form of the ST
+## slot in mer2.  If so, install start as the ST slot.
+setST <- function(mer, start)
+{
+    ST <- mer@ST
+    if (!is.list(start) || length(start) != length(ST) ||
+        !all.equal(names(ST), names(start)))
+        stop(paste("start must be a list of length", length(ST),
+                   "with names\n", paste(names(ST), collapse = ',')))
+    for (i in seq(along = start)) {
+        if (class(start[[i]]) != class(ST[[i]]) ||
+            !all.equal(dim(start[[i]]), dim(ST[[i]])))
+            stop(paste("start[[", i, "]] must be of class '", class(ST[[i]]),
+                       "' and dimension ", paste(dim(ST[[i]]), collapse = ','),
+                       sep = ''))
+    }
+    mer@ST <- start
+    mer
+}
+
 lmer2 <- function(formula, data, family = gaussian,
                  method = c("REML", "ML", "PQL", "Laplace", "AGQ"),
                  control = list(), start = NULL,
@@ -1238,7 +1258,8 @@ lmer2 <- function(formula, data, family = gaussian,
     if (fltype < 0) {
         mer <- .Call(mer2_create, fl, Zt, t(X), as.double(Y),
                      method == "REML", nc, cnames, fr$offset,
-                     fr$weights)
+                     fr$weights) 
+        if (!is.null(start)) mer <- setST(mer, start)
         ## indicator of constrained parameters
         const <- unlist(lapply(mer@nc,
                                function(n) rep(1:0, c(n, (n*(n - 1))/2))))
@@ -1248,8 +1269,9 @@ lmer2 <- function(formula, data, family = gaussian,
                                  .Call(mer2_setPars, mer, x), as.integer(0)),
                            lower = ifelse(const, 0, -Inf),
                            control = list(trace = cv$msVerbose,
-                           iter.max = cv$msMaxIter,
-                           rel.tol = abs(0.001/.Call(mer2_deviance, mer, 0))))
+                           iter.max = cv$msMaxIter
+                           #, rel.tol = abs(0.001/.Call(mer2_deviance, mer, 0))
+                           ))
         if (optimRes$convergence)
             warning(paste("nlminb failed to converge:", optimRes$message))
         ## ensure mer parameters are at the converged value
