@@ -1,4 +1,5 @@
 SEXP attr_hidden
+    lme4_ASym,
     lme4_DSym,
     lme4_DimSym,
     lme4_DimNamesSym,
@@ -8,9 +9,11 @@ SEXP attr_hidden
     lme4_RXXSym,
     lme4_RZXSym,
     lme4_RZXinvSym,
+    lme4_STSym,
     lme4_XSym,
     lme4_XtXSym,
     lme4_XtySym,
+    lme4_ZXytSym,
     lme4_ZZpOSym,
     lme4_ZtSym,
     lme4_ZtXSym,
@@ -21,6 +24,7 @@ SEXP attr_hidden
     lme4_devCompSym,
     lme4_devianceSym,
     lme4_diagSym,
+    lme4_dimsSym,
     lme4_factorSym,
     lme4_fixefSym,
     lme4_flistSym,
